@@ -236,8 +236,11 @@ void ShortcutDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
                 QTreeWidgetItem *item=li.at(k);
                 QString id = item->data(0, Qt::UserRole).toString();
                 QStringList ids=id.split("/");
-                if(ids.value(0,"")!=progType)
-                    li.removeAll(item);
+                if(ids.value(0,"")!=progType){
+                    if(progType=="pdf" || ids.value(0,"")=="pdf"){
+                        li.removeAll(item);
+                    }
+                }
             }
 			REQUIRE(treeWidget->topLevelItem(1));
 			REQUIRE(treeWidget->topLevelItem(1)->childCount() >= 1);
@@ -607,6 +610,7 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
     // ai chat
     connect(ui.cbAIProvider, SIGNAL(currentIndexChanged(int)), this, SLOT(aiProviderChanged(int)));
     connect(ui.pbRetrieveModels, &QPushButton::clicked, this, &ConfigDialog::retrieveModels);
+    connect(ui.pbResetAIURL, &QPushButton::clicked, this, &ConfigDialog::resetAIURL);
     // fill in the known models
     aiFillInKnownModels();
 
@@ -688,6 +692,7 @@ void ConfigDialog::revertClicked()
  */
 void ConfigDialog::aiProviderChanged(int provider)
 {
+    bool activateCustomURL=false;
     switch(provider){
     case 0:
         ui.cbAIPreferredModel->clear();
@@ -699,14 +704,18 @@ void ConfigDialog::aiProviderChanged(int provider)
         break;
     case 1:
         ui.cbAIPreferredModel->clear();
+        ui.cbAIPreferredModel->addItem("gpt-4o-mini");
         ui.cbAIPreferredModel->addItem("gpt-3.5-turbo");
         ui.cbAIPreferredModel->addItem("gpt-4");
-        ui.cbAIPreferredModel->addItem("gpt-4-turbo-preview");
+        ui.cbAIPreferredModel->addItem("gpt-4o");
         break;
     default:
         ui.cbAIPreferredModel->clear();
+        activateCustomURL=true;
         break;
     }
+    ui.leAIAPIURL->setEnabled(activateCustomURL);
+    ui.pbResetAIURL->setEnabled(activateCustomURL);
 }
 /*!
  * \brief retieve the current list of available model from AI provider
@@ -738,6 +747,13 @@ void ConfigDialog::retrieveModels()
         manager->get(request);
     }
 }
+/*!
+ * \brief reset custom ai api url to default
+ */
+void ConfigDialog::resetAIURL()
+{
+    ui.leAIAPIURL->setText("http://localhost:8080/v1/chat/completions");
+}
 
 void ConfigDialog::modelsRetrieved(QNetworkReply *reply)
 {
